package com.ruoyi.mall.service;

import java.util.List;
import com.ruoyi.mall.domain.MallGoodsTips;

/**
 * mallService接口
 * 
 * @author ruoyi
 * @date 2021-12-31
 */
public interface IMallGoodsTipsService 
{
    /**
     * 查询mall
     * 
     * @param id mall主键
     * @return mall
     */
    public MallGoodsTips selectMallGoodsTipsById(Long id);

    /**
     * 查询mall列表
     * 
     * @param mallGoodsTips mall
     * @return mall集合
     */
    public List<MallGoodsTips> selectMallGoodsTipsList(MallGoodsTips mallGoodsTips);

    /**
     * 新增mall
     * 
     * @param mallGoodsTips mall
     * @return 结果
     */
    public int insertMallGoodsTips(MallGoodsTips mallGoodsTips);

    /**
     * 修改mall
     * 
     * @param mallGoodsTips mall
     * @return 结果
     */
    public int updateMallGoodsTips(MallGoodsTips mallGoodsTips);

    /**
     * 批量删除mall
     * 
     * @param ids 需要删除的mall主键集合
     * @return 结果
     */
    public int deleteMallGoodsTipsByIds(Long[] ids);

    /**
     * 删除mall信息
     * 
     * @param id mall主键
     * @return 结果
     */
    public int deleteMallGoodsTipsById(Long id);
}
